@@ -79,7 +79,12 @@ end
 
 function class:setOptions (options)
   options = options or {}
-  options.papersize = options.papersize or "a4"
+  -- Classes that add options with dependencies should explicitly handle them, then exempt them from furthur processing.
+  -- The landscape option is handled explicitly before papersize, then the "rest" of options that are not interdependent.
+  self.options.landscape = SU.boolean(options.landscape, false)
+  options.landscape = nil
+  self.options.papersize = options.papersize or "a4"
+  options.papersize = nil
   for option, value in pairs(options) do
     self.options[option] = value
   end
@@ -101,10 +106,16 @@ function class:declareOptions ()
     end
     return self._name
   end)
+  self:declareOption("landscape", function(_, landscape)
+    if landscape then
+      self.landscape = landscape
+    end
+    return self.landscape
+  end)
   self:declareOption("papersize", function (_, size)
     if size then
       self.papersize = size
-      SILE.documentState.paperSize = SILE.papersize(size)
+      SILE.documentState.paperSize = SILE.papersize(size, self.options.landscape)
       SILE.documentState.orgPaperSize = SILE.documentState.paperSize
       SILE.newFrame({
         id = "page",
@@ -575,8 +586,8 @@ function class:finish ()
   end
   SILE.typesetter:runHooks("pageend") -- normally run by the typesetter
   self:endPage()
-  if SILE.typesetter then
-    assert(SILE.typesetter:isQueueEmpty(), "queues not empty")
+  if SILE.typesetter and not SILE.typesetter:isQueueEmpty() then
+    SU.error("Queues are not empty as expected after ending last page", true)
   end
   SILE.outputter:finish()
   self:runHooks("finish")
