@@ -51,27 +51,30 @@ function class:_init (options)
 end
 
 function class:endPage ()
-  if (self:oddPage() and SILE.scratch.headers.right) then
-    SILE.typesetNaturally(SILE.getFrame("runningHead"), function ()
-      SILE.settings:toplevelState()
-      SILE.settings:set("current.parindent", SILE.nodefactory.glue())
-      SILE.settings:set("document.lskip", SILE.nodefactory.glue())
-      SILE.settings:set("document.rskip", SILE.nodefactory.glue())
-      -- SILE.settings:set("typesetter.parfillskip", SILE.nodefactory.glue())
-      SILE.process(SILE.scratch.headers.right)
-      SILE.call("par")
-    end)
-  elseif (not(self:oddPage()) and SILE.scratch.headers.left) then
+  if not SILE.scratch.headers.skipthispage then
+    if self:oddPage() and SILE.scratch.headers.right then
       SILE.typesetNaturally(SILE.getFrame("runningHead"), function ()
         SILE.settings:toplevelState()
         SILE.settings:set("current.parindent", SILE.nodefactory.glue())
         SILE.settings:set("document.lskip", SILE.nodefactory.glue())
         SILE.settings:set("document.rskip", SILE.nodefactory.glue())
-          -- SILE.settings:set("typesetter.parfillskip", SILE.nodefactory.glue())
+        -- SILE.settings:set("typesetter.parfillskip", SILE.nodefactory.glue())
+        SILE.process(SILE.scratch.headers.right)
+        SILE.call("par")
+      end)
+    elseif not self:oddPage() and SILE.scratch.headers.left then
+      SILE.typesetNaturally(SILE.getFrame("runningHead"), function ()
+        SILE.settings:toplevelState()
+        SILE.settings:set("current.parindent", SILE.nodefactory.glue())
+        SILE.settings:set("document.lskip", SILE.nodefactory.glue())
+        SILE.settings:set("document.rskip", SILE.nodefactory.glue())
+        -- SILE.settings:set("typesetter.parfillskip", SILE.nodefactory.glue())
         SILE.process(SILE.scratch.headers.left)
         SILE.call("par")
       end)
+    end
   end
+  SILE.scratch.headers.skipthispage = false
   return plain.endPage(self)
 end
 
@@ -115,6 +118,7 @@ function class:registerCommands ()
 
   self:registerCommand("book:chapter:post", function (_, _)
     SILE.call("par")
+    SILE.call("noindent")
   end)
 
   self:registerCommand("book:section:post", function (_, _)
@@ -134,7 +138,8 @@ function class:registerCommands ()
   end)
 
   self:registerCommand("chapter", function (options, content)
-    SILE.call("open-double-page")
+    SILE.typesetter:leaveHmode()
+    SILE.call("open-spread", { double = false })
     SILE.call("noindent")
     SILE.scratch.headers.right = nil
     SILE.call("set-counter", { id = "footnote", value = 1 })
@@ -160,6 +165,9 @@ function class:registerCommands ()
     end)
     SILE.call("bigskip")
     SILE.call("nofoliothispage")
+    -- English typography (notably) expects the first paragraph under a section
+    -- not to be indented. Frenchies, don't use this class :)
+    SILE.call("noindent")
   end, "Begin a new chapter")
 
   self:registerCommand("section", function (options, content)
@@ -199,6 +207,9 @@ function class:registerCommands ()
     SILE.call("novbreak")
     SILE.call("bigskip")
     SILE.call("novbreak")
+    -- English typography (notably) expects the first paragraph under a section
+    -- not to be indented. Frenchies, don't use this class :)
+    SILE.call("noindent")
     SILE.typesetter:inhibitLeading()
   end, "Begin a new section")
 
@@ -225,6 +236,9 @@ function class:registerCommands ()
     SILE.call("novbreak")
     SILE.call("medskip")
     SILE.call("novbreak")
+    -- English typography (notably) expects the first paragraph under a section
+    -- not to be indented. Frenchies, don't use this class :)
+    SILE.call("noindent")
     SILE.typesetter:inhibitLeading()
   end, "Begin a new subsection")
 
