@@ -1,5 +1,5 @@
 local deprecator = function ()
-  SU.deprecated("SILE.settings.*", "SILE.settings:*", "0.13.0", "0.14.0")
+  SU.deprecated("SILE.settings.*", "SILE.settings:*", "0.13.0", "0.15.0")
   return SILE.settings
 end
 
@@ -91,7 +91,7 @@ function settings:_init()
     else
       self:set(parameter, value, makedefault, reset)
     end
-  end, "Set a SILE parameter <parameter> to value <value> (restoring the value afterwards if <content> is provided)")
+  end, "Set a SILE parameter <parameter> to value <value> (restoring the value afterwards if <content> is provided)", nil, true)
 
 end
 
@@ -111,10 +111,15 @@ function settings:declare (spec)
   if spec.name then
     SU.deprecated("'name' argument of SILE.settings:declare", "'parameter' argument of SILE.settings:declare", "0.10.10", "0.11.0")
   end
+  if self.declarations[spec.parameter] then
+    SU.debug("settings", "Attempt to re-declare setting: " .. spec.parameter)
+    return
+  end
   self.declarations[spec.parameter] = spec
   self:set(spec.parameter, spec.default, true)
 end
 
+--- Reset all settings to their default value.
 function settings:reset ()
   if not self then self = deprecator() end
   for k,_ in pairs(self.state) do
@@ -122,16 +127,27 @@ function settings:reset ()
   end
 end
 
+--- Restore all settings to the value they had in the top-level state,
+-- that is at the head of the settings stack (normally the document
+-- level).
 function settings:toplevelState ()
   if not self then self = deprecator() end
   if #self.stateQueue ~= 0 then
-    for k,_ in pairs(self.state) do
-      self:set(k, self.stateQueue[1][k])
+    for parameter, _ in pairs(self.state) do
+      -- Bypass self:set() as the latter performs some tests and a cast,
+      -- but the setting might not have been defined in the top level state
+      -- (in which case, assume the default value).
+      self.state[parameter] = self.stateQueue[1][parameter] or self.defaults[parameter]
     end
   end
 end
 
 function settings:get (parameter)
+  -- HACK FIXME https://github.com/sile-typesetter/sile/issues/1699
+  -- See comment on set() below.
+  if parameter == "current.parindent" then
+    return SILE.typesetter and SILE.typesetter.state.parindent
+  end
   if not parameter then self, parameter = deprecator(), self end
   if not self.declarations[parameter] then
     SU.error("Undefined setting '"..parameter.."'")
@@ -144,6 +160,30 @@ function settings:get (parameter)
 end
 
 function settings:set (parameter, value, makedefault, reset)
+  -- HACK FIXME https://github.com/sile-typesetter/sile/issues/1699
+  -- Anything dubbed current.xxx should likely NOT be a "setting" (subject
+  -- to being pushed/popped via temporary stacking) and actually has its
+  -- own lifecycle (e.g. reset for the next paragraph).
+  -- These should be rather typesetter states, or something to that extent
+  -- yet to clarify. Notably, current.parindent falls in that category,
+  -- BUT probably current.hangAfter and current.hangIndent too.
+  -- To avoid breaking too much code yet without being sure of the solution,
+  -- we implement a hack of sorts for current.parindent only.
+  -- Note moreover that current.parindent is currently probably a bad concept
+  -- anyway:
+  --   - It can be nil (= document.parindent applies)
+  --   - It can be a zero-glue (\noindent, ragged environments, etc.)
+  --   - It can be a valued glue set to document.parindent
+  --     (e.g. from \indent, and document.parindent thus applies)
+  --   - It could be another valued glue (uh, use case to ascertain)
+  -- What we would _likely_ only need to track is whether document.parindent
+  -- applies or not on the paragraph just composed afterwards...
+  if parameter == "current.parindent" then
+    if SILE.typesetter and not SILE.typesetter.state.hmodeOnly then
+      SILE.typesetter.state.parindent = SU.cast("glue or nil", value)
+    end
+    return
+  end
   if type(self) ~= "table" then self, parameter, value, makedefault, reset = deprecator(), self, parameter, value, makedefault end
   if not self.declarations[parameter] then
     SU.error("Undefined setting '"..parameter.."'")
