@@ -68,12 +68,12 @@ SILE.nodeMakers.base = pl.class({
       return chardata[cp]
     end,
 
-    isPunctuation = function (self, char)
-      return self.isPunctuationType[self:charData(char).category]
+    isActiveNonBreakingSpace = function (self, char)
+      return self:isNonBreakingSpace(char) and not SILE.settings:get("languages.fixedNbsp")
     end,
 
-    isSpace = function (self, char)
-      return self.isSpaceType[self:charData(char).linebreak]
+    isBreaking = function (self, char)
+      return self.breakingTypes[self:charData(char).linebreak]
     end,
 
     isNonBreakingSpace = function (self, char)
@@ -81,26 +81,31 @@ SILE.nodeMakers.base = pl.class({
       return c.contextname and c.contextname == "nobreakspace"
     end,
 
-    isActiveNonBreakingSpace = function (self, char)
-      return self:isNonBreakingSpace(char) and not SILE.settings:get("languages.fixedNbsp")
+    isPunctuation = function (self, char)
+      return self.puctuationTypes[self:charData(char).category]
     end,
 
-    isBreaking = function (self, char)
-      return self.isBreakingType[self:charData(char).linebreak]
+    isSpace = function (self, char)
+      return self.spaceTypes[self:charData(char).linebreak]
     end,
+
     isQuote = function (self, char)
-      return self.isQuoteType[self:charData(char).linebreak]
-    end
+      return self.quoteTypes[self:charData(char).linebreak]
+    end,
+
+    isWord = function (self, char)
+      return self.wordTypes[self:charData(char).linebreak]
+    end,
 
   })
 
 SILE.nodeMakers.unicode = pl.class(SILE.nodeMakers.base)
 
-SILE.nodeMakers.unicode.isWordType = { cm = true }
-SILE.nodeMakers.unicode.isSpaceType = { sp = true }
-SILE.nodeMakers.unicode.isBreakingType = { ba = true, zw = true }
-SILE.nodeMakers.unicode.isPunctuationType = { po = true }
-SILE.nodeMakers.unicode.isQuoteType = {} -- quote linebreak category is ambiguous depending on the language
+SILE.nodeMakers.unicode.breakingTypes = { ba = true, zw = true }
+SILE.nodeMakers.unicode.puctuationTypes = { po = true }
+SILE.nodeMakers.unicode.quoteTypes = {} -- quote linebreak category is ambiguous depending on the language
+SILE.nodeMakers.unicode.spaceTypes = { sp = true }
+SILE.nodeMakers.unicode.wordTypes = { cm = true }
 
 function SILE.nodeMakers.unicode:dealWith (item)
   local char = item.text
@@ -119,7 +124,7 @@ function SILE.nodeMakers.unicode:dealWith (item)
   elseif self:isQuote(item.text) then
     self:addToken(char, item)
     self:makeToken()
-  elseif self.lasttype and (thistype and thistype ~= self.lasttype and not self.isWordType[thistype]) then
+  elseif self.lasttype and (thistype and thistype ~= self.lasttype and not self:isWord(thistype)) then
     self:addToken(char, item)
   else
     self:letterspace()
@@ -188,6 +193,23 @@ function SILE.nodeMakers.unicode:handleWordBreak (item)
   end
 end
 
+function SILE.nodeMakers.unicode:_handleWordBreakRepeatHyphen (item)
+  -- According to some language rules, when a break occurs at an explicit hyphen,
+  -- the hyphen gets repeated at the beginning of the new line
+  if item.text == "-" then
+    self:addToken(item.text, item)
+    self:makeToken()
+    if self.lastnode ~= "discretionary" then
+      coroutine.yield(SILE.nodefactory.discretionary({
+        postbreak = SILE.shaper:createNnodes("-", self.options)
+      }))
+      self.lastnode = "discretionary"
+    end
+  else
+    SILE.nodeMakers.unicode.handleWordBreak(self, item)
+  end
+end
+
 function SILE.nodeMakers.unicode:handleLineBreak (item, subtype)
   -- Because we are in charge of paragraphing, we
   -- will override space-type line breaks, and treat
@@ -206,6 +228,16 @@ function SILE.nodeMakers.unicode:handleLineBreak (item, subtype)
   self.lasttype = chardata[cp] and chardata[cp].linebreak
 end
 
+function SILE.nodeMakers.unicode:_handleLineBreakRepeatHyphen (item, subtype)
+  if self.lastnode == "discretionary" then
+    -- Initial word boundary after a discretionary:
+    -- Bypass it and just deal with the token.
+    self:dealWith(item)
+  else
+    SILE.nodeMakers.unicode.handleLineBreak(self, item, subtype)
+  end
+end
+
 function SILE.nodeMakers.unicode:iterator (items)
   local fulltext = ""
   for i = 1, #items do
