@@ -38,8 +38,8 @@ package.documentation = [[
 \begin{document}
 \use[module=packages.background]
 The \autodoc:package{background} package allows you to set the color of the canvas background (by drawing a solid color block the full size of the page on page initialization).
-The package provides a \autodoc:command{\background} command which requires at least one parameter, \autodoc:parameter{color=<color specification>}, and sets the backgound of the current and all following pages to that color.
-If setting only the current page background different from the default is desired, an extra parameter \autodoc:parameter{allpages=false} can be passed.
+The package provides a \autodoc:command{\background} command which requires at least one parameter, \autodoc:parameter{color=<color specification>}, and sets the background of the current and all following pages to that color.
+If you want to set only the current page background different from the default, use the parameter \autodoc:parameter{allpages=false}.
 The color specification in the same as specified in the \autodoc:package{color} package.
 
 \background[color=#e9d8ba,allpages=false]
