@@ -1,3 +1,8 @@
+local base = require("packages.base")
+
+local package = pl.class(base)
+package._name = "features"
+
 local lpeg = require("lpeg")
 
 local R, S, P, C = lpeg.R, lpeg.S, lpeg.P, lpeg.C
@@ -109,13 +114,13 @@ local featurestring = Cf(Ct"" * tag^0, rawset)
 -- Parser for fontspec strings
 -- Refer to fontspec.pdf (see doc), Chapter 3, Table 4 (p. 37)
 local fontspecsafe = R("AZ", "az", "09") + P":"
-local fontspecws = SILE.parserBits.whitespace^0
-local fontspecsep = P"," * fontspecws
+local ws = SILE.parserBits.ws
+local fontspecsep = P"," * ws
 local fontspecname = C(fontspecsafe^1)
-local fontspeclist = fontspecws * P"{" *
-                     Ct(fontspecws * fontspecname *
-                        (fontspecsep * fontspecname * fontspecws)^0) *
-                     P"}" * fontspecws
+local fontspeclist = ws * P"{" *
+                     Ct(ws * fontspecname *
+                        (fontspecsep * fontspecname * ws)^0) *
+                     P"}" * ws
 
 local otFeatures = pl.class(pl.Map)
 
@@ -178,21 +183,21 @@ end
 
 local fontfn = SILE.Commands.font
 
-local function registerCommands (_)
+function package:registerCommands ()
 
-  SILE.registerCommand("add-font-feature", function (options, _)
+  self:registerCommand("add-font-feature", function (options, _)
     local otfeatures = otFeatures()
     otfeatures:loadOptions(options)
     SILE.settings:set("font.features", tostring(otfeatures))
   end)
 
-  SILE.registerCommand("remove-font-feature", function(options, _)
+  self:registerCommand("remove-font-feature", function(options, _)
     local otfeatures = otFeatures()
     otfeatures:unloadOptions(options)
     SILE.settings:set("font.features", tostring(otfeatures))
   end)
 
-  SILE.registerCommand("font", function (options, content)
+  self:registerCommand("font", function (options, content)
     local otfeatures = otFeatures()
     -- It is guaranteed that future releases of SILE will not implement non-OT \font
     -- features with capital letters.
@@ -211,45 +216,35 @@ local function registerCommands (_)
 
 end
 
-return {
-  registerCommands = registerCommands,
-  documentation = [[
+package.documentation = [[
 \begin{document}
-As mentioned in Chapter 3, SILE automatically applies ligatures defined by the fonts
-that you use. These ligatures are defined by tables of \em{features} within
-the font file. As well as ligatures (multiple glyphs displayed as a single glyph),
-the features tables also declare other glyph substitutions.
+SILE automatically applies ligatures defined by the fonts that you use.
+These ligatures are defined by tables of \em{features} within the font file.
+As well as ligatures (multiple glyphs displayed as a single glyph), the features tables also declare other glyph substitutions.
 
-The \autodoc:package{features} package provides an interface to selecting the features that you
-want SILE to apply to a font. The features available will be specific to the font file;
-some fonts come with documentation explaining their supported features. Discussion
-of OpenType features is beyond the scope of this manual.
+The standard \autodoc:command{\font} command provides an interface to selecting the features that you want SILE to apply to a font.
+The features available will be specific to the font file; some fonts come with documentation explaining their supported features.
+Discussion of OpenType features is beyond the scope of this manual.
 
-These features can be turned on and off by passing ‘raw’ feature names to the
-\autodoc:command{\font} command like so:
+These features can be turned on and off by passing “raw” feature names to the \autodoc:command{\font} command like so:
 
-\begin{verbatim}
-\line
-\\font[features="+dlig,+hlig"]{...} \% turn on discretionary and historic ligatures
-\line
-\end{verbatim}
+\begin[type=autodoc:codeblock]{raw}
+\font[features="+dlig,+hlig"]{...} % turn on discretionary and historic ligatures
+\end{raw}
 
-However, this is unwieldy and requires memorizing the feature codes. \autodoc:package{features}
-provides two commands, \autodoc:command{\add-font-feature} and \autodoc:command{\remove-font-feature},
-which make it easier to access OpenType features. The interface is patterned on the
-TeX package \code{fontspec}; for full documentation of the OpenType features supported,
-see the documentation for that package.\footnote{\code{http://texdoc.net/texmf-dist/doc/latex/fontspec/fontspec.pdf}}
+However, this is unwieldy and requires memorizing the feature codes.
 
-Here is how you would turn on discretionary and historic ligatures with the \autodoc:package{features}
-package:
+The \autodoc:package{features} package provides two commands, \autodoc:command{\add-font-feature} and \autodoc:command{\remove-font-feature}, which make it easier to access OpenType features.
+The interface is patterned on the TeX package \code{fontspec}; for full documentation of the OpenType features supported, see the documentation for that package.\footnote{\code{http://texdoc.net/texmf-dist/doc/latex/fontspec/fontspec.pdf}}
 
-\begin{verbatim}
-\line
-\\add-font-feature[Ligatures=Rare]\\add-font-feature[Ligatures=Discretionary]
+Here is how you would turn on discretionary and historic ligatures with the \autodoc:package{features} package:
+
+\begin[type=autodoc:codeblock]{raw}
+\add-font-feature[Ligatures=Rare]\add-font-feature[Ligatures=Discretionary]
 ...
-\\remove-font-feature[Ligatures=Rare]\\remove-font-feature[Ligatures=Discretionary]
-\line
-\end{verbatim}
+\remove-font-feature[Ligatures=Rare]\remove-font-feature[Ligatures=Discretionary]
+\end{raw}
 \end{document}
 ]]
-}
+
+return package
